==> UniProt.ws_2.0.1.tar.gz: UniProt.ws/man/colsAndKeytypes.Rd <==
\name{UNIPROTKB}

\alias{UNIPROTKB}
\alias{UNIPARC}
\alias{UNIREF50}
\alias{UNIREF90}
\alias{UNIREF100}
\alias{EMBL/GENBANK/DDBJ}
\alias{EMBL/GENBANK/DDBJ_CDS}
\alias{PIR}
\alias{UNIGENE}
\alias{ENTREZ_GENE}
\alias{GI_NUMBER*}
\alias{IPI}
\alias{REFSEQ_PROTEIN}
\alias{REFSEQ_NUCLEOTIDE}
\alias{PDB}
\alias{DISPROT}
\alias{HSSP}
\alias{DIP}
\alias{MINT}
\alias{ALLERGOME}
\alias{MEROPS}
\alias{PEROXIBASE}
\alias{PPTASEDB}
\alias{REBASE}
\alias{TCDB}
\alias{PHOSSITE}
\alias{DMDM}
\alias{AARHUS/GHENT-2DPAGE}
\alias{ECO2DBASE}
\alias{WORLD-2DPAGE}
\alias{DNASU}
\alias{ENSEMBL}
\alias{ENSEMBL_PROTEIN}
\alias{ENSEMBL_TRANSCRIPT}
\alias{ENSEMBL_GENOMES}
\alias{ENSEMBL_GENOMES PROTEIN}
\alias{ENSEMBL_GENOMES TRANSCRIPT}
\alias{GENEID}
\alias{GENOMEREVIEWS}
\alias{KEGG}
\alias{PATRIC}
\alias{TIGR}
\alias{UCSC}
\alias{VECTORBASE}
\alias{AGD}
\alias{ARACHNOSERVER}
\alias{CGD}
\alias{CONOSERVER}
\alias{CYGD}
\alias{DICTYBASE}
\alias{ECHOBASE}
\alias{ECOGENE}
\alias{EUHCVDB}
\alias{EUPATHDB}
\alias{FLYBASE}
\alias{GENECARDS}
\alias{GENEFARM}
\alias{GENOLIST}
\alias{H-INVDB}
\alias{HGNC}
\alias{HPA}
\alias{LEGIOLIST}
\alias{LEPROMA}
\alias{MAIZEGDB}
\alias{MIM}
\alias{MGI}
\alias{NEXTPROT}
\alias{ORPHANET}
\alias{PHARMGKB}
\alias{POMBASE}
\alias{PSEUDOCAP}
\alias{RGD}
\alias{SGD}
\alias{TAIR}
\alias{TUBERCULIST}
\alias{WORMBASE}
\alias{WORMBASE_TRANSCRIPT}
\alias{WORMBASE_PROTEIN}
\alias{XENBASE}
\alias{ZFIN}
\alias{EGGNOG}
\alias{GENETREE}
\alias{HOGENOM}
\alias{HOVERGEN}
\alias{KO}
\alias{OMA}
\alias{ORTHODB}
\alias{PROTCLUSTDB}
\alias{BIOCYC}
\alias{REACTOME}
\alias{UNIPATHWAY}
\alias{CLEANEX}
\alias{GERMONLINE}
\alias{DRUGBANK}
\alias{GENOMERNAI}
\alias{NEXTBIO}
\alias{CITATION}
\alias{CLUSTERS}
\alias{COMMENTS}
\alias{DOMAINS}
\alias{DOMAIN}
\alias{EC}
\alias{ID}
\alias{ENTRY NAME}
\alias{EXISTENCE}
\alias{FAMILIES}
\alias{FEATURES}
\alias{GENES}
\alias{GO}
\alias{GO-ID}
\alias{INTERPRO}
\alias{INTERACTOR}
\alias{KEYWORDS}
\alias{KEYWORD-ID}
\alias{LAST-MODIFIED}
\alias{LENGTH}
\alias{ORGANISM}
\alias{ORGANISM-ID}
\alias{PATHWAY}
\alias{PROTEIN NAMES}
\alias{REVIEWED}
\alias{SCORE}
\alias{SEQUENCE}
\alias{3D}
\alias{SUBCELLULAR LOCATIONS}
\alias{TAXON}
\alias{TOOLS}
\alias{VERSION}
\alias{VIRUS_HOSTS}
\alias{DATABASE(PFAM)}
\alias{DATABASE(PDB)}

\title{Descriptions of available values for \code{cols} and \code{keytypes}.}


\description{
  This manual page enumerates the kinds of data represented by the
  values returned when the user calls \code{cols} or \code{keytypes}
}


\details{  
  All the possible values for \code{cols} and \code{keytypes} are listed
  below.  Users will have to actually use these methods to learn which
  of the following possible values actually apply in their case.
  
  \describe{
    \item{:UNIPROTKB}{The central ID for UniProt and swissprot}
    \item{:UNIPARC}{UniParc}
    \item{:UNIREF50}{UniRef50}
    \item{:UNIREF90}{UniRef90}
    \item{:UNIREF100}{UniRef100}
    \item{:EMBL/GENBANK/DDBJ}{EMBL/GenBank/DDBJ}
    \item{:EMBL/GENBANK/DDBJ_CDS}{EMBL/GenBank/DDBJ CDS}
    \item{:PIR}{PIR}
    \item{:UNIGENE}{UniGene}
    \item{:ENTREZ_GENE}{Entrez Gene (GeneID)}
    \item{:GI_NUMBER*}{GI number}
    \item{:IPI}{IPI}
    \item{:REFSEQ_PROTEIN}{RefSeq Protein}
    \item{:REFSEQ_NUCLEOTIDE}{RefSeq Nucleotide}
    \item{:PDB}{PDB}
    \item{:DISPROT}{DisProt}
    \item{:HSSP}{HSSP}
    \item{:DIP}{DIP}
    \item{:MINT}{MINT}
    \item{:ALLERGOME}{Allergome}
    \item{:MEROPS}{MEROPS}
    \item{:PEROXIBASE}{PeroxiBase}
    \item{:PPTASEDB}{PptaseDB}
    \item{:REBASE}{REBASE}
    \item{:TCDB}{TCDB}
    \item{:PHOSSITE}{PhosSite}
    \item{:DMDM}{DMDM}
    \item{:AARHUS/GHENT-2DPAGE}{Aarhus/Ghent-2DPAGE}
    \item{:ECO2DBASE}{ECO2DBASE}
    \item{:WORLD-2DPAGE}{World-2DPAGE}
    \item{:DNASU}{DNASU}
    \item{:ENSEMBL}{Ensembl}
    \item{:ENSEMBL_PROTEIN}{Ensembl Protein}
    \item{:ENSEMBL_TRANSCRIPT}{Ensembl Transcript}
    \item{:ENSEMBL_GENOMES}{Ensembl Genomes}
    \item{:ENSEMBL_GENOMES PROTEIN}{Ensembl Genomes Protein}
    \item{:ENSEMBL_GENOMES TRANSCRIPT}{Ensembl Genomes Transcript}
    \item{:GENEID}{GeneID}
    \item{:GENOMEREVIEWS}{GenomeReviews}
    \item{:KEGG}{KEGG}
    \item{:PATRIC}{PATRIC}
    \item{:TIGR}{TIGR}
    \item{:UCSC}{UCSC}
    \item{:VECTORBASE}{VectorBase}
    \item{:AGD}{AGD}
    \item{:ARACHNOSERVER}{ArachnoServer}
    \item{:CGD}{CGD}
    \item{:CONOSERVER}{ConoServer}
    \item{:CYGD}{CYGD}
    \item{:DICTYBASE}{dictyBase}
    \item{:ECHOBASE}{EchoBASE}
    \item{:ECOGENE}{EcoGene}
    \item{:EUHCVDB}{euHCVdb}
    \item{:EUPATHDB}{EuPathDB}
    \item{:FLYBASE}{FlyBase}
    \item{:GENECARDS}{GeneCards}
    \item{:GENEFARM}{GeneFarm}
    \item{:GENOLIST}{GenoList}
    \item{:H-INVDB}{H-InvDB}
    \item{:HGNC}{HGNC}
    \item{:HPA}{HPA}
    \item{:LEGIOLIST}{LegioList}
    \item{:LEPROMA}{Leproma}
    \item{:MAIZEGDB}{MaizeGDB}
    \item{:MIM}{MIM}
    \item{:MGI}{MGI}
    \item{:NEXTPROT}{neXtProt}
    \item{:ORPHANET}{Orphanet}
    \item{:PHARMGKB}{PharmGKB}
    \item{:POMBASE}{PomBase}
    \item{:PSEUDOCAP}{PseudoCAP}
    \item{:RGD}{RGD}
    \item{:SGD}{SGD}
    \item{:TAIR}{TAIR}
    \item{:TUBERCULIST}{TubercuList}
    \item{:WORMBASE}{WormBase}
    \item{:WORMBASE_TRANSCRIPT}{WormBase Transcript}
    \item{:WORMBASE_PROTEIN}{WormBase Protein}
    \item{:XENBASE}{Xenbase}
    \item{:ZFIN}{ZFIN}
    \item{:EGGNOG}{eggNOG}
    \item{:GENETREE}{GeneTree}
    \item{:HOGENOM}{HOGENOM}
    \item{:HOVERGEN}{HOVERGEN}
    \item{:KO}{KO}
    \item{:OMA}{OMA}
    \item{:ORTHODB}{OrthoDB}
    \item{:PROTCLUSTDB}{ProtClustDB}
    \item{:BIOCYC}{BioCyc}
    \item{:REACTOME}{Reactome}
    \item{:UNIPATHWAY}{UniPathWay}
    \item{:CLEANEX}{CleanEx}
    \item{:GERMONLINE}{GermOnline}
    \item{:DRUGBANK}{DrugBank}
    \item{:GENOMERNAI}{GenomeRNAi}
    \item{:NEXTBIO}{NextBio}
    \item{:CITATION}{citations}
    \item{:CLUSTERS}{clusters}
    \item{:COMMENTS}{comments}
    \item{:DOMAINS}{domains}
    \item{:DOMAIN}{domain}
    \item{:EC}{ec ID}
    \item{:ID}{ID}
    \item{:ENTRY NAME}{entry name}
    \item{:EXISTENCE}{existence}
    \item{:FAMILIES}{families}
    \item{:FEATURES}{features}
    \item{:GENES}{genes}
    \item{:GO}{go term}
    \item{:GO-ID}{go id}
    \item{:INTERPRO}{interpro}
    \item{:INTERACTOR}{interactor}
    \item{:KEYWORDS}{keywords}
    \item{:KEYWORD-ID}{keyword-id}
    \item{:LAST-MODIFIED}{last-modified}
    \item{:LENGTH}{length}
    \item{:ORGANISM}{organism}
    \item{:ORGANISM-ID}{organism-id}
    \item{:PATHWAY}{pathway}
    \item{:PROTEIN NAMES}{protein names}
    \item{:REVIEWED}{reviewed}
    \item{:SCORE}{score}
    \item{:SEQUENCE}{sequence}
    \item{:3D}{3d}
    \item{:SUBCELLULAR LOCATIONS}{subcellular locations}
    \item{:TAXON}{taxon}
    \item{:TOOLS}{tools}
    \item{:VERSION}{version}
    \item{:VIRUS_HOSTS}{virus hosts}
    \item{:DATABASE(PFAM)}{PFAM ids}
    \item{:DATABASE(PDB)}{PDB ids}

    
    \item{:}{}
    
  }

  
}


\author{Marc Carlson}


\examples{
  library(UniProt.ws)
  ## List the possible values for cols
  cols(UniProt.ws)
  ## List the possible values for keytypes
  keytypes(UniProt.ws)
  ## get some values back
  ## list all possible keys of type entrez gene ID.
  ## (this process is not instantaneous)
  if(interactive()){
    keys <- head(keys(UniProt.ws, keytype="UNIPROTKB"))
    keys
  }
  select(UniProt.ws, keys=c("P31946","P62258"), cols=c("PDB","SEQUENCE"),
  keytype="UNIPROTKB")
}


\keyword{utilities}
\keyword{manip}

==> UniProt.ws_2.4.2.tar.gz: UniProt.ws/man/colsAndKeytypes.Rd <==
\name{UNIPROTKB}

\alias{UNIPROTKB}
\alias{UNIPARC}
\alias{UNIREF50}
\alias{UNIREF90}
\alias{UNIREF100}
\alias{EMBL/GENBANK/DDBJ}
\alias{EMBL/GENBANK/DDBJ_CDS}
\alias{PIR}
\alias{UNIGENE}
\alias{ENTREZ_GENE}
\alias{GI_NUMBER*}
\alias{IPI}
\alias{REFSEQ_PROTEIN}
\alias{REFSEQ_NUCLEOTIDE}
\alias{PDB}
\alias{DISPROT}
\alias{HSSP}
\alias{DIP}
\alias{MINT}
\alias{ALLERGOME}
\alias{MEROPS}
\alias{PEROXIBASE}
\alias{PPTASEDB}
\alias{REBASE}
\alias{TCDB}
\alias{PHOSSITE}
\alias{DMDM}
\alias{AARHUS/GHENT-2DPAGE}
\alias{ECO2DBASE}
\alias{WORLD-2DPAGE}
\alias{DNASU}
\alias{ENSEMBL}
\alias{ENSEMBL_PROTEIN}
\alias{ENSEMBL_TRANSCRIPT}
\alias{ENSEMBL_GENOMES}
\alias{ENSEMBL_GENOMES PROTEIN}
\alias{ENSEMBL_GENOMES TRANSCRIPT}
\alias{GENEID}
\alias{GENOMEREVIEWS}
\alias{KEGG}
\alias{PATRIC}
\alias{TIGR}
\alias{UCSC}
\alias{VECTORBASE}
\alias{AGD}
\alias{ARACHNOSERVER}
\alias{CGD}
\alias{CONOSERVER}
\alias{CYGD}
\alias{DICTYBASE}
\alias{ECHOBASE}
\alias{ECOGENE}
\alias{EUHCVDB}
\alias{EUPATHDB}
\alias{FLYBASE}
\alias{GENECARDS}
\alias{GENEFARM}
\alias{GENOLIST}
\alias{H-INVDB}
\alias{HGNC}
\alias{HPA}
\alias{LEGIOLIST}
\alias{LEPROMA}
\alias{MAIZEGDB}
\alias{MIM}
\alias{MGI}
\alias{NEXTPROT}
\alias{ORPHANET}
\alias{PHARMGKB}
\alias{POMBASE}
\alias{PSEUDOCAP}
\alias{RGD}
\alias{SGD}
\alias{TAIR}
\alias{TUBERCULIST}
\alias{WORMBASE}
\alias{WORMBASE_TRANSCRIPT}
\alias{WORMBASE_PROTEIN}
\alias{XENBASE}
\alias{ZFIN}
\alias{EGGNOG}
\alias{GENETREE}
\alias{HOGENOM}
\alias{HOVERGEN}
\alias{KO}
\alias{OMA}
\alias{ORTHODB}
\alias{PROTCLUSTDB}
\alias{BIOCYC}
\alias{REACTOME}
\alias{UNIPATHWAY}
\alias{CLEANEX}
\alias{GERMONLINE}
\alias{DRUGBANK}
\alias{GENOMERNAI}
\alias{NEXTBIO}
\alias{CITATION}
\alias{CLUSTERS}
\alias{COMMENTS}
\alias{DOMAINS}
\alias{DOMAIN}
\alias{EC}
\alias{ID}
\alias{ENTRY NAME}
\alias{EXISTENCE}
\alias{FAMILIES}
\alias{FEATURES}
\alias{GENES}
\alias{GO}
\alias{GO-ID}
\alias{INTERPRO}
\alias{INTERACTOR}
\alias{KEYWORDS}
\alias{KEYWORD-ID}
\alias{LAST-MODIFIED}
\alias{LENGTH}
\alias{ORGANISM}
\alias{ORGANISM-ID}
\alias{PATHWAY}
\alias{PROTEIN NAMES}
\alias{REVIEWED}
\alias{SCORE}
\alias{SEQUENCE}
\alias{3D}
\alias{SUBCELLULAR LOCATIONS}
\alias{TAXON}
\alias{TOOLS}
\alias{VERSION}
\alias{VIRUS_HOSTS}
\alias{DATABASE(PFAM)}
\alias{DATABASE(PDB)}

\title{Descriptions of available values for \code{columns} and \code{keytypes}.}


\description{
  This manual page enumerates the kinds of data represented by the
  values returned when the user calls \code{columns} or \code{keytypes}
}


\details{  
  All the possible values for \code{columns} and \code{keytypes} are listed
  below.  Users will have to actually use these methods to learn which
  of the following possible values actually apply in their case.
  
  \describe{
    \item{:UNIPROTKB}{The central ID for UniProt and swissprot}
    \item{:UNIPARC}{UniParc}
    \item{:UNIREF50}{UniRef50}
    \item{:UNIREF90}{UniRef90}
    \item{:UNIREF100}{UniRef100}
    \item{:EMBL/GENBANK/DDBJ}{EMBL/GenBank/DDBJ}
    \item{:EMBL/GENBANK/DDBJ_CDS}{EMBL/GenBank/DDBJ CDS}
    \item{:PIR}{PIR}
    \item{:UNIGENE}{UniGene}
    \item{:ENTREZ_GENE}{Entrez Gene (GeneID)}
    \item{:GI_NUMBER*}{GI number}
    \item{:IPI}{IPI}
    \item{:REFSEQ_PROTEIN}{RefSeq Protein}
    \item{:REFSEQ_NUCLEOTIDE}{RefSeq Nucleotide}
    \item{:PDB}{PDB}
    \item{:DISPROT}{DisProt}
    \item{:HSSP}{HSSP}
    \item{:DIP}{DIP}
    \item{:MINT}{MINT}
    \item{:ALLERGOME}{Allergome}
    \item{:MEROPS}{MEROPS}
    \item{:PEROXIBASE}{PeroxiBase}
    \item{:PPTASEDB}{PptaseDB}
    \item{:REBASE}{REBASE}
    \item{:TCDB}{TCDB}
    \item{:PHOSSITE}{PhosSite}
    \item{:DMDM}{DMDM}
    \item{:AARHUS/GHENT-2DPAGE}{Aarhus/Ghent-2DPAGE}
    \item{:ECO2DBASE}{ECO2DBASE}
    \item{:WORLD-2DPAGE}{World-2DPAGE}
    \item{:DNASU}{DNASU}
    \item{:ENSEMBL}{Ensembl}
    \item{:ENSEMBL_PROTEIN}{Ensembl Protein}
    \item{:ENSEMBL_TRANSCRIPT}{Ensembl Transcript}
    \item{:ENSEMBL_GENOMES}{Ensembl Genomes}
    \item{:ENSEMBL_GENOMES PROTEIN}{Ensembl Genomes Protein}
    \item{:ENSEMBL_GENOMES TRANSCRIPT}{Ensembl Genomes Transcript}
    \item{:GENEID}{GeneID}
    \item{:GENOMEREVIEWS}{GenomeReviews}
    \item{:KEGG}{KEGG}
    \item{:PATRIC}{PATRIC}
    \item{:TIGR}{TIGR}
    \item{:UCSC}{UCSC}
    \item{:VECTORBASE}{VectorBase}
    \item{:AGD}{AGD}
    \item{:ARACHNOSERVER}{ArachnoServer}
    \item{:CGD}{CGD}
    \item{:CONOSERVER}{ConoServer}
    \item{:CYGD}{CYGD}
    \item{:DICTYBASE}{dictyBase}
    \item{:ECHOBASE}{EchoBASE}
    \item{:ECOGENE}{EcoGene}
    \item{:EUHCVDB}{euHCVdb}
    \item{:EUPATHDB}{EuPathDB}
    \item{:FLYBASE}{FlyBase}
    \item{:GENECARDS}{GeneCards}
    \item{:GENEFARM}{GeneFarm}
    \item{:GENOLIST}{GenoList}
    \item{:H-INVDB}{H-InvDB}
    \item{:HGNC}{HGNC}
    \item{:HPA}{HPA}
    \item{:LEGIOLIST}{LegioList}
    \item{:LEPROMA}{Leproma}
    \item{:MAIZEGDB}{MaizeGDB}
    \item{:MIM}{MIM}
    \item{:MGI}{MGI}
    \item{:NEXTPROT}{neXtProt}
    \item{:ORPHANET}{Orphanet}
    \item{:PHARMGKB}{PharmGKB}
    \item{:POMBASE}{PomBase}
    \item{:PSEUDOCAP}{PseudoCAP}
    \item{:RGD}{RGD}
    \item{:SGD}{SGD}
    \item{:TAIR}{TAIR}
    \item{:TUBERCULIST}{TubercuList}
    \item{:WORMBASE}{WormBase}
    \item{:WORMBASE_TRANSCRIPT}{WormBase Transcript}
    \item{:WORMBASE_PROTEIN}{WormBase Protein}
    \item{:XENBASE}{Xenbase}
    \item{:ZFIN}{ZFIN}
    \item{:EGGNOG}{eggNOG}
    \item{:GENETREE}{GeneTree}
    \item{:HOGENOM}{HOGENOM}
    \item{:HOVERGEN}{HOVERGEN}
    \item{:KO}{KO}
    \item{:OMA}{OMA}
    \item{:ORTHODB}{OrthoDB}
    \item{:PROTCLUSTDB}{ProtClustDB}
    \item{:BIOCYC}{BioCyc}
    \item{:REACTOME}{Reactome}
    \item{:UNIPATHWAY}{UniPathWay}
    \item{:CLEANEX}{CleanEx}
    \item{:GERMONLINE}{GermOnline}
    \item{:DRUGBANK}{DrugBank}
    \item{:GENOMERNAI}{GenomeRNAi}
    \item{:NEXTBIO}{NextBio}
    \item{:CITATION}{citations}
    \item{:CLUSTERS}{clusters}
    \item{:COMMENTS}{comments}
    \item{:DOMAINS}{domains}
    \item{:DOMAIN}{domain}
    \item{:EC}{ec ID}
    \item{:ID}{ID}
    \item{:ENTRY NAME}{entry name}
    \item{:EXISTENCE}{existence}
    \item{:FAMILIES}{families}
    \item{:FEATURES}{features}
    \item{:GENES}{genes}
    \item{:GO}{go term}
    \item{:GO-ID}{go id}
    \item{:INTERPRO}{interpro}
    \item{:INTERACTOR}{interactor}
    \item{:KEYWORDS}{keywords}
    \item{:KEYWORD-ID}{keyword-id}
    \item{:LAST-MODIFIED}{last-modified}
    \item{:LENGTH}{length}
    \item{:ORGANISM}{organism}
    \item{:ORGANISM-ID}{organism-id}
    \item{:PATHWAY}{pathway}
    \item{:PROTEIN NAMES}{protein names}
    \item{:REVIEWED}{reviewed}
    \item{:SCORE}{score}
    \item{:SEQUENCE}{sequence}
    \item{:3D}{3d}
    \item{:SUBCELLULAR LOCATIONS}{subcellular locations}
    \item{:TAXON}{taxon}
    \item{:TOOLS}{tools}
    \item{:VERSION}{version}
    \item{:VIRUS_HOSTS}{virus hosts}
    \item{:DATABASE(PFAM)}{PFAM ids}
    \item{:DATABASE(PDB)}{PDB ids}

    
    \item{:}{}
    
  }

  
}


\author{Marc Carlson}


\examples{
  library(UniProt.ws)
  ## List the possible values for columns
  columns(UniProt.ws)
  ## List the possible values for keytypes
  keytypes(UniProt.ws)
  ## get some values back
  ## list all possible keys of type entrez gene ID.
  ## (this process is not instantaneous)
  if(interactive()){
    keys <- head(keys(UniProt.ws, keytype="UNIPROTKB"))
    keys
  }
  select(UniProt.ws, keys=c("P31946","P62258"), columns=c("PDB","SEQUENCE"),
  keytype="UNIPROTKB")
}


\keyword{utilities}
\keyword{manip}
